==> spirit_hub-0.1.1.31.tar.gz: spirit_hub-0.1.1.31/e2e/cypress/e2e/features/modals/share_modal.js <==
import { Given, When, Then } from '@badeball/cypress-cucumber-preprocessor';
import '../../../support/step_definitions/modal_steps';

let tagset_ids, directory_id, john_id, jack_id, josh_id;

Given('There is a directory with some docs', () => {
  tagset_ids = [];

  cy.appFactories([['create_list', 'tagset_doc', 5, 'with_state', 'with_file']]).then(records => {
    records[0].forEach(record => {
      tagset_ids.push(record.id);
    });
  });
  cy.appFactories([['create', 'tagset_directory', 'with_journal_entries', { responsible: '1', id: '1', tagset_ids: tagset_ids }]]).then(records => {
    directory_id = records[0].id;
  });
});

Given('There are similar docs that have been shared already', () => {
  cy.appFactories([['create', 'suggest_from_tagset_doc_to_tagset_doc', { from_tagset_doc_id: tagset_ids[0], to_tagset_doc_id: tagset_ids[1] }]]);
  cy.appFactories([['create', 'suggest_from_tagset_doc_to_tagset_doc', { from_tagset_doc_id: tagset_ids[0], to_tagset_doc_id: tagset_ids[2] }]]);

  cy.appFactories([['create', 'journal_entry', { code: 'DOC_SHARED', tagset_id: tagset_ids[1], opts: { to: [john_id] } }]]);
  cy.appFactories([['create', 'journal_entry', { code: 'DOC_SHARED', tagset_id: tagset_ids[2], opts: { to: [jack_id, josh_id] } }]]);
});

When('I visit the directory url', () => {
  cy.visit(`/spirit_hub/directories/${directory_id}/index`);
});

Given('There are existing users I want to share a doc with', () => {
  cy.appFactories([['create', 'user', { email: 'john@test.com', first_name: 'John', last_name: 'Doe' }]]).then(records => { john_id = records[0].id });
  cy.appFactories([['create', 'user', { email: 'jack@test.com', first_name: 'Jack', last_name: 'Black' }]]).then(records => { jack_id = records[0].id });
  cy.appFactories([['create', 'user', { email: 'josh@test.com', first_name: 'Josh', last_name: 'Homme' }]]).then(records => { josh_id = records[0].id });
});

Given('There are existing user groups I want to share a doc with', () => {
  const uids = {};

  cy.appFactories([['create', 'user', { email: 'john@test.com', first_name: 'John', last_name: 'Doe' }]]).then(records => {
    uids.user1 = records[0].id;
  });
  cy.appFactories([['create', 'user', { email: 'jack@test.com', first_name: 'Jack', last_name: 'Black' }]]).then(records => {
    uids.user2 = records[0].id;
  });
  cy.appFactories([['create', 'user', { email: 'josh@test.com', first_name: 'Josh', last_name: 'Homme' }]]).then(records => {
    uids.user3 = records[0].id;

    cy.appFactories([['create', 'group', { name: 'Group One', users_ids: [uids.user1, uids.user2] }]]);
    cy.appFactories([['create', 'group', { name: 'Group Two', users_ids: [uids.user3] }]]);
  });
});

Given('There are existing external contacts I want to share a doc with', () => {
  cy.appFactories([['create', 'contact', { email: 'john@test.com', first_name: 'John', last_name: 'Doe' }]]);
  cy.appFactories([['create', 'contact', { email: 'jack@test.com', first_name: 'Jack', last_name: 'Black' }]]);
  cy.appFactories([['create', 'contact', { email: 'josh@test.com', first_name: 'Josh', last_name: 'Homme' }]]);
});

Then('I can share the doc with the existing users', option => {
  cy.get('form[action*="/spirit_hub/tagsets/form/share"] button[type="submit"]').first().click();

  cy.get('select[name="to[]"]').next('div').click();
  cy.contains('.ss-list:visible > .ss-option', 'John Doe (john@test.com)').first().click({ force: true });
  cy.get('select[name="cc[]"]').next('div').click();
  cy.contains('.ss-list:visible > .ss-option', 'Jack Black (jack@test.com)').first().click({ force: true });
  cy.get('select[name="bcc[]"]').next('div').click();
  cy.contains('.ss-list:visible > .ss-option', 'Josh Homme (josh@test.com)').first().click({ force: true });
  cy.get('input[name="subject"]').first().type('Hey');
  cy.get('textarea[name="message"]').first().type('Hello there!');
  cy.get('form[action*="/share"] button[type="submit"]').first().click();

  cy.get('div[id*="informed_badges"]').first().find('img').should('have.length', 3);
  cy.get('div[id*="informed_badges"] img[src*="JD"]').should('exist');
  cy.get('div[id*="informed_badges"] img[src*="JB"]').should('exist');
  cy.get('div[id*="informed_badges"] img[src*="JH"]').should('exist');
});

Then('I can share the doc with the existing user groups', option => {
  cy.get('form[action*="/spirit_hub/tagsets/form/share"] button[type="submit"]').first().click();

  cy.get('select[name="to[]"]').next('div').click();
  cy.contains('.ss-list:visible > .ss-option', 'Group One (2 membres)').first().click({ force: true });
  cy.get('select[name="cc[]"]').next('div').click();
  cy.contains('.ss-list:visible > .ss-option', 'Group Two (1 membres)').first().click({ force: true });
  cy.get('input[name="subject"]').first().type('Hey');
  cy.get('textarea[name="message"]').first().type('Hello there!');
  cy.get('form[action*="/share"] button[type="submit"]').first().click();

  cy.get('div[id*="informed_badges"]').first().find('img').should('have.length', 3);
  cy.get('div[id*="informed_badges"] img[src*="JD"]').should('exist');
  cy.get('div[id*="informed_badges"] img[src*="JB"]').should('exist');
  cy.get('div[id*="informed_badges"] img[src*="JH"]').should('exist');
});

Then('I can share the doc with the external contacts', option => {
  cy.get('form[action*="/spirit_hub/tagsets/form/share"] button[type="submit"]').first().click();

  cy.get('select[name="to[]"]').next('div').click();
  cy.contains('.ss-list:visible > .ss-option', 'John Doe (john@test.com)').first().click({ force: true });
  cy.get('select[name="cc[]"]').next('div').click();
  cy.contains('.ss-list:visible > .ss-option', 'Jack Black (jack@test.com)').first().click({ force: true });
  cy.get('select[name="bcc[]"]').next('div').click();
  cy.contains('.ss-list:visible > .ss-option', 'Josh Homme (josh@test.com)').first().click({ force: true });
  cy.get('input[name="subject"]').first().type('Hey');
  cy.get('textarea[name="message"]').first().type('Hello there!');
  cy.get('form[action*="/share"] button[type="submit"]').first().click();

  cy.get('div[id*="informed_badges"]').first().find('.rounded-full').should('have.length', 3);
  cy.get('div[id*="informed_badges"] .rounded-full').contains('JD').should('exist');
  cy.get('div[id*="informed_badges"] .rounded-full').contains('JB').should('exist');
  cy.get('div[id*="informed_badges"] .rounded-full').contains('JH').should('exist');
});

Then('I can share the doc with new external contacts', option => {
  cy.get('form[action*="/spirit_hub/tagsets/form/share"] button[type="submit"]').first().click();

  cy.get('select[name="to[]"]').next('div').click();
  cy.get('.ss-search:visible input[type="search"]').first().type('invalid@email');
  cy.get('.ss-search:visible .ss-addable').first().click();
  cy.get('.ss-value-text:visible').should('not.exist'); // Does not accept invalid emails

  cy.get('.ss-search:visible input[type="search"]').first().clear();
  cy.get('.ss-search:visible input[type="search"]').first().type('john.doe@gmail.com');
  cy.get('.ss-search:visible .ss-addable').first().click();
  cy.get('.ss-value-text:visible').contains('john.doe@gmail.com').should('exist');

  cy.get('input[name="subject"]').first().type('Hey');
  cy.get('textarea[name="message"]').first().type('Hello there!');
  cy.get('form[action*="/share"] button[type="submit"]').first().click();

  cy.get('div[id*="informed_badges"]').first().find('.rounded-full').should('have.length', 1);
  cy.get('div[id*="informed_badges"] .rounded-full').contains('J').should('exist');
});

Then('I can share the doc with the user groups', option => {
  cy.get('form[action*="/spirit_hub/tagsets/form/share"] button[type="submit"]').first().click();

  cy.get('select[name="to[]"]').next('div').click();
  cy.contains('.ss-list > .ss-option', 'John Doe (john@test.com)').first().click({ force: true });
  cy.get('select[name="cc[]"]').next('div').click();
  cy.contains('.ss-list > .ss-option', 'Jack Black (jack@test.com)').first().click({ force: true });
  cy.get('select[name="to[]"]').next('div').click();
  cy.contains('.ss-list > .ss-option', 'Josh Homme (josh@test.com)').first().click({ force: true });
  cy.get('input[name="subject"]').first().type('Hey');
  cy.get('textarea[name="message"]').first().type('Hello there!');
  cy.get('form[action*="/share"] button[type="submit"]').first().click();

  cy.get('div[id*="informed_badges"]').first().find('img').should('have.length', 3);
  cy.get('div[id*="informed_badges"] img[src*="JD"]').should('exist');
  cy.get('div[id*="informed_badges"] img[src*="JB"]').should('exist');
  cy.get('div[id*="informed_badges"] img[src*="JH"]').should('exist');
});

Then('I can apply the AI suggestion for the TO recipients only', option => {
  cy.get('form[action*="/spirit_hub/tagsets/form/share"] button[type="submit"]').first().click();

  cy.get('select[name="to[]"]').next('div').find('.ss-value-text:visible').should('not.exist');
  cy.get('select[name="cc[]"]').next('div').find('.ss-value-text:visible').should('not.exist');
  cy.get('select[name="bcc[]"]').next('div').find('.ss-value-text:visible').should('not.exist');

  cy.get('a').contains("Suggestion d'IA").click();
  cy.get('select[name="to[]"]').next('div').find('.ss-value-text:visible').contains('john@test.com').should('exist');
  cy.get('select[name="to[]"]').next('div').find('.ss-value-text:visible').contains('jack@test.com').should('exist');
  cy.get('select[name="to[]"]').next('div').find('.ss-value-text:visible').contains('josh@test.com').should('exist');

  cy.get('select[name="cc[]"]').next('div').find('.ss-value-text:visible').should('not.exist');
  cy.get('select[name="bcc[]"]').next('div').find('.ss-value-text:visible').should('not.exist');
});

When('I click on the share button', () => {
  cy.get('form[action="/spirit_hub/tagsets/form/share"] button').first().click();
});

Then('The doc title is visible in the modal', () => {
  cy.get('[data-controller="modal"] header h2').next('div').contains('Doc Title 1 (dog.jpg)').should('exist');
});

When('I fill the share form', () => {
  cy.get('select[name="to[]"]').next('div').click();
  cy.contains('.ss-list:visible > .ss-option', 'Admin User (admin@test.com)').first().click({ force: true });

  cy.get('input[name="subject"]').first().type('Hey');
  cy.get('textarea[name="message"]').first().type('Hello there!');
});

When('I add some files as attachments', () => {
  // Attach docs
  cy.get('input[type="file"][name="attachments[]"]').attachFile(['files/example.pdf', 'files/example.jpeg']);

  // Attach existing tagsets
  cy.get('select[name="attached_tagset_ids[]"]').next('div').click();
  cy.get('.ss-search:visible > input[type="search"]').first().type('Doc')
  cy.contains('.ss-list:visible > .ss-option', 'Doc Title 5').first().click({ force: true });
});

When('I submit the form', () => {
  cy.get('form[action*="/share"] button[type="submit"]').first().click({ force: true });
});

When('I see the classify modal', () => {
  cy.get('header h2').contains('Classer');
});

==> spirit_hub-0.1.1.32.tar.gz: spirit_hub-0.1.1.32/e2e/cypress/e2e/features/modals/share_modal.js <==
import { Given, When, Then } from '@badeball/cypress-cucumber-preprocessor';
import '../../../support/step_definitions/modal_steps';

let tagset_ids, directory_id, john_id, jack_id, josh_id;

Given('There is a directory with some docs', () => {
  tagset_ids = [];

  cy.appFactories([['create', 'tagset_doc', 'with_state', 'with_file', { filename: 'dog.jpg' }]]).then(records => {
    tagset_ids.push(records[0].id);
  });
  cy.appFactories([['create', 'tagset_doc', 'with_state', 'with_file', { filename: 'one_page.pdf' }]]).then(records => {
    tagset_ids.push(records[0].id);
  });
  cy.appFactories([['create', 'tagset_doc', 'with_state', 'with_file', { filename: 'pdf_sample.pdf' }]]).then(records => {
    tagset_ids.push(records[0].id);
  });
  cy.appFactories([['create', 'tagset_doc', 'with_state', 'with_file', { filename: 'pdf_sample2.pdf' }]]).then(records => {
    tagset_ids.push(records[0].id);
  });
  cy.appFactories([['create', 'tagset_doc', 'with_state', 'with_file', { filename: 'pdf_sample3.pdf' }]]).then(records => {
    tagset_ids.push(records[0].id);
  });
  cy.appFactories([['create', 'tagset_directory', 'with_journal_entries', { responsible: '1', id: '1', tagset_ids: tagset_ids }]]).then(records => {
    directory_id = records[0].id;
  });
});

Given('There are similar docs that have been shared already', () => {
  cy.appFactories([['create', 'suggest_from_tagset_doc_to_tagset_doc', { from_tagset_doc_id: tagset_ids[0], to_tagset_doc_id: tagset_ids[1] }]]);
  cy.appFactories([['create', 'suggest_from_tagset_doc_to_tagset_doc', { from_tagset_doc_id: tagset_ids[0], to_tagset_doc_id: tagset_ids[2] }]]);

  cy.appFactories([['create', 'journal_entry', { code: 'DOC_SHARED', tagset_id: tagset_ids[1], opts: { to: [john_id] } }]]);
  cy.appFactories([['create', 'journal_entry', { code: 'DOC_SHARED', tagset_id: tagset_ids[2], opts: { to: [jack_id, josh_id] } }]]);
});

When('I visit the directory url', () => {
  cy.visit(`/spirit_hub/directories/${directory_id}/index`);
});

Given('There are existing users I want to share a doc with', () => {
  cy.appFactories([['create', 'user', { email: 'john@test.com', first_name: 'John', last_name: 'Doe' }]]).then(records => { john_id = records[0].id });
  cy.appFactories([['create', 'user', { email: 'jack@test.com', first_name: 'Jack', last_name: 'Black' }]]).then(records => { jack_id = records[0].id });
  cy.appFactories([['create', 'user', { email: 'josh@test.com', first_name: 'Josh', last_name: 'Homme' }]]).then(records => { josh_id = records[0].id });
});

Given('There are existing user groups I want to share a doc with', () => {
  const uids = {};

  cy.appFactories([['create', 'user', { email: 'john@test.com', first_name: 'John', last_name: 'Doe' }]]).then(records => {
    uids.user1 = records[0].id;
  });
  cy.appFactories([['create', 'user', { email: 'jack@test.com', first_name: 'Jack', last_name: 'Black' }]]).then(records => {
    uids.user2 = records[0].id;
  });
  cy.appFactories([['create', 'user', { email: 'josh@test.com', first_name: 'Josh', last_name: 'Homme' }]]).then(records => {
    uids.user3 = records[0].id;

    cy.appFactories([['create', 'group', { name: 'Group One', users_ids: [uids.user1, uids.user2] }]]);
    cy.appFactories([['create', 'group', { name: 'Group Two', users_ids: [uids.user3] }]]);
  });
});

Given('There are existing external contacts I want to share a doc with', () => {
  cy.appFactories([['create', 'contact', { email: 'john@test.com', first_name: 'John', last_name: 'Doe' }]]);
  cy.appFactories([['create', 'contact', { email: 'jack@test.com', first_name: 'Jack', last_name: 'Black' }]]);
  cy.appFactories([['create', 'contact', { email: 'josh@test.com', first_name: 'Josh', last_name: 'Homme' }]]);
});

Then('I can share the doc with the existing users', option => {
  cy.get('form[action*="/spirit_hub/tagsets/form/share"] button[type="submit"]').first().click();

  cy.get('select[name="to[]"]').next('div').click();
  cy.contains('.ss-list:visible > .ss-option', 'John Doe (john@test.com)').first().click({ force: true });
  cy.get('select[name="cc[]"]').next('div').click();
  cy.contains('.ss-list:visible > .ss-option', 'Jack Black (jack@test.com)').first().click({ force: true });
  cy.get('select[name="bcc[]"]').next('div').click();
  cy.contains('.ss-list:visible > .ss-option', 'Josh Homme (josh@test.com)').first().click({ force: true });
  cy.get('input[name="subject"]').first().type('Hey');
  cy.get('textarea[name="message"]').first().type('Hello there!');
  cy.get('form[action*="/share"] button[type="submit"]').first().click();

  cy.get('div[id*="informed_badges"]').first().find('img').should('have.length', 3);
  cy.get('div[id*="informed_badges"] img[src*="JD"]').should('exist');
  cy.get('div[id*="informed_badges"] img[src*="JB"]').should('exist');
  cy.get('div[id*="informed_badges"] img[src*="JH"]').should('exist');
});

Then('I can share the doc with the existing user groups', option => {
  cy.get('form[action*="/spirit_hub/tagsets/form/share"] button[type="submit"]').first().click();

  cy.get('select[name="to[]"]').next('div').click();
  cy.contains('.ss-list:visible > .ss-option', 'Group One (2 membres)').first().click({ force: true });
  cy.get('select[name="cc[]"]').next('div').click();
  cy.contains('.ss-list:visible > .ss-option', 'Group Two (1 membres)').first().click({ force: true });
  cy.get('input[name="subject"]').first().type('Hey');
  cy.get('textarea[name="message"]').first().type('Hello there!');
  cy.get('form[action*="/share"] button[type="submit"]').first().click();

  cy.get('div[id*="informed_badges"]').first().find('img').should('have.length', 3);
  cy.get('div[id*="informed_badges"] img[src*="JD"]').should('exist');
  cy.get('div[id*="informed_badges"] img[src*="JB"]').should('exist');
  cy.get('div[id*="informed_badges"] img[src*="JH"]').should('exist');
});

Then('I can share the doc with the external contacts', option => {
  cy.get('form[action*="/spirit_hub/tagsets/form/share"] button[type="submit"]').first().click();

  cy.get('select[name="to[]"]').next('div').click();
  cy.contains('.ss-list:visible > .ss-option', 'John Doe (john@test.com)').first().click({ force: true });
  cy.get('select[name="cc[]"]').next('div').click();
  cy.contains('.ss-list:visible > .ss-option', 'Jack Black (jack@test.com)').first().click({ force: true });
  cy.get('select[name="bcc[]"]').next('div').click();
  cy.contains('.ss-list:visible > .ss-option', 'Josh Homme (josh@test.com)').first().click({ force: true });
  cy.get('input[name="subject"]').first().type('Hey');
  cy.get('textarea[name="message"]').first().type('Hello there!');
  cy.get('form[action*="/share"] button[type="submit"]').first().click();

  cy.get('div[id*="informed_badges"]').first().find('.rounded-full').should('have.length', 3);
  cy.get('div[id*="informed_badges"] .rounded-full').contains('JD').should('exist');
  cy.get('div[id*="informed_badges"] .rounded-full').contains('JB').should('exist');
  cy.get('div[id*="informed_badges"] .rounded-full').contains('JH').should('exist');
});

Then('I can share the doc with new external contacts', option => {
  cy.get('form[action*="/spirit_hub/tagsets/form/share"] button[type="submit"]').first().click();

  cy.get('select[name="to[]"]').next('div').click();
  cy.get('.ss-search:visible input[type="search"]').first().type('invalid@email');
  cy.get('.ss-search:visible .ss-addable').first().click();
  cy.get('.ss-value-text:visible').should('not.exist'); // Does not accept invalid emails

  cy.get('.ss-search:visible input[type="search"]').first().clear();
  cy.get('.ss-search:visible input[type="search"]').first().type('john.doe@gmail.com');
  cy.get('.ss-search:visible .ss-addable').first().click();
  cy.get('.ss-value-text:visible').contains('john.doe@gmail.com').should('exist');

  cy.get('input[name="subject"]').first().type('Hey');
  cy.get('textarea[name="message"]').first().type('Hello there!');
  cy.get('form[action*="/share"] button[type="submit"]').first().click();

  cy.get('div[id*="informed_badges"]').first().find('.rounded-full').should('have.length', 1);
  cy.get('div[id*="informed_badges"] .rounded-full').contains('J').should('exist');
});

Then('I can share the doc with the user groups', option => {
  cy.get('form[action*="/spirit_hub/tagsets/form/share"] button[type="submit"]').first().click();

  cy.get('select[name="to[]"]').next('div').click();
  cy.contains('.ss-list > .ss-option', 'John Doe (john@test.com)').first().click({ force: true });
  cy.get('select[name="cc[]"]').next('div').click();
  cy.contains('.ss-list > .ss-option', 'Jack Black (jack@test.com)').first().click({ force: true });
  cy.get('select[name="to[]"]').next('div').click();
  cy.contains('.ss-list > .ss-option', 'Josh Homme (josh@test.com)').first().click({ force: true });
  cy.get('input[name="subject"]').first().type('Hey');
  cy.get('textarea[name="message"]').first().type('Hello there!');
  cy.get('form[action*="/share"] button[type="submit"]').first().click();

  cy.get('div[id*="informed_badges"]').first().find('img').should('have.length', 3);
  cy.get('div[id*="informed_badges"] img[src*="JD"]').should('exist');
  cy.get('div[id*="informed_badges"] img[src*="JB"]').should('exist');
  cy.get('div[id*="informed_badges"] img[src*="JH"]').should('exist');
});

Then('I can apply the AI suggestion for the TO recipients only', option => {
  cy.get('form[action*="/spirit_hub/tagsets/form/share"] button[type="submit"]').first().click();

  cy.get('select[name="to[]"]').next('div').find('.ss-value-text:visible').should('not.exist');
  cy.get('select[name="cc[]"]').next('div').find('.ss-value-text:visible').should('not.exist');
  cy.get('select[name="bcc[]"]').next('div').find('.ss-value-text:visible').should('not.exist');

  cy.get('a').contains("Suggestion d'IA").click();
  cy.get('select[name="to[]"]').next('div').find('.ss-value-text:visible').contains('john@test.com').should('exist');
  cy.get('select[name="to[]"]').next('div').find('.ss-value-text:visible').contains('jack@test.com').should('exist');
  cy.get('select[name="to[]"]').next('div').find('.ss-value-text:visible').contains('josh@test.com').should('exist');

  cy.get('select[name="cc[]"]').next('div').find('.ss-value-text:visible').should('not.exist');
  cy.get('select[name="bcc[]"]').next('div').find('.ss-value-text:visible').should('not.exist');
});

When('I click on the share button', () => {
  cy.get('form[action="/spirit_hub/tagsets/form/share"] button').first().click();
});

Then('The doc title is visible in the modal', () => {
  cy.get('[data-controller="modal"] header h2').next('div').contains('Doc Title 1 (dog.jpg)').should('exist');
});

When('I fill the share form', () => {
  cy.get('select[name="to[]"]').next('div').click();
  cy.contains('.ss-list:visible > .ss-option', 'Admin User (admin@test.com)').first().click({ force: true });

  cy.get('input[name="subject"]').first().type('Hey');
  cy.get('textarea[name="message"]').first().type('Hello there!');
});

When('I add some files as attachments', () => {
  // Attach docs
  cy.get('input[type="file"][name="attachments[]"]').attachFile(['files/example.png']);

  // Attach existing tagsets
  cy.get('select[name="attached_tagset_ids[]"]').next('div').click();
  cy.get('.ss-search:visible > input[type="search"]').first().type('Doc')
  cy.contains('.ss-list:visible > .ss-option', 'Doc Title 5').first().click({ force: true });
});

When('I submit the form', () => {
  cy.get('form[action*="/share"] button[type="submit"]').first().click({ force: true });
});

When('I see the classify modal', () => {
  cy.get('header h2').contains('Classer');
});
